==> sigutils-2.2.7.tar.gz: sigutils-2.2.7/SigUtils/numero.py <==
# -*- coding: iso-8859-1 -*-
from SigUtils import formatastring

__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.06"
__DataAlteracao__ = "27/10/2009"
import sys

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print('numeros.py\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tTratamento de valores numericos'
        else:
           print('\n\nnumeros.py - Tratamento de valores numericos \n'
                   +'Versao: '+ __Versao__ + '\n'
                   +'Data: '+ __DataAlteracao__ + '\n')
    except:
       print('\n\nnumeros.py - Tratamento de valores numericos \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n')


class Numero:
   """sintaxe: Numero(ValorNumerico) -> Objeto 
      Numero trata valores numericos, formatando para strings
      ou truncando / arredondando
      Para qualquer erro, retorna -1
                                      """

   def __init__(self, numero):
       self.codErro=0
       self.listaDeErros=(
          "vazio",                                                                # 0
          "Tamanho da parte inteira maior do que o tamanho especificado",         # 1
          "Tamanho da parte fracionada maior do que o tamanho especificado",      # 2
          "'trunc_round' so pode ser 't' ou 'r'",                                 # 3
          "Valor Informando nao  numerico",                                      # 4
          "vazio")
       try:
          a=str(numero)
          if len(a) == 0:
             self.numero=0.0
          else:   
             self.numero = float(a)
       except:
          self.codErro=4 


   def numeroToStr(self, tam_int=0, tam_fra=0):
       """numeroToStr, converte numeros em strings
          Sintaxe: NumeroToStr([tam_int], [[tam_fra])
          'tam_int',  o tamanho da parte inteira 
          'tam_fra"  o tamanho da parte fracionada
          se tam_int e/ou tam_fra nao forem informados o retorno da funcao 
             ser exatamente do tamanho real do numero, se informado, ser
             expandido para o tamanho especificado
                   
                                         """
       try:
          if self.codErro==4:
             return -1
          sNumero=str(self.numero)
          if tam_int == 0:
             return sNumero
          sInteiro = str(int(self.numero))
          if len(sInteiro) > tam_int:
             self.codErro=1
             return -1
          sInteiro = formatastring.formataString(sInteiro, tam_int, '0', 'E')
          sFracao=''
          iniciou = 'N'
          for x in sNumero:
              if x == '.': 
                 iniciou = 'S'
                 continue
              if iniciou == 'S':
                 sFracao=sFracao+x
          if len(sFracao) > tam_fra :
             sFracao=sFracao[:tam_fra]
          sFracao= formatastring.formataString(sFracao, tam_fra, '0', 'D')
          sNumero=sInteiro+'.'+sFracao
          return sNumero
       except:
          self.codErro = 4
          return -1
   def numeroToFloat(self, tam_dec=0, trunc_round='r'):
       """numeroToFloat, Converte numeros em float
        Sintaxe: NumeroToFloat([tam_dec], [trunc_round])
        'tam_dec'  o tamanho da parte decimal(fracao)
        'trunc_round' especifica se  para truncar ou arredondar caso o numero informado seja maior
        se 'tam_dec' nao for informado, o retorno da funcao sera  exatamente do tamanho real do numero,
           se for informado, sera truncado ou arredondado conforme 'trunc_round' = 't' ou 'r'
                                                    """
       try:
          if self.codErro==4:
             return -1
          if trunc_round != 'r' and trunc_round !='t':
             self.codErro=3
             return -1
          fNumero=float(self.numero)       
          if tam_dec == 0:
             return fNumero
          sInteiro = str(int(fNumero))
          sFracao = str(fNumero - int(sInteiro))
          if len(sFracao) <= tam_dec:
             return fNumero
          if trunc_round == 'r':
             fNumero=round(fNumero, tam_dec)
             sInteiro = str(int(fNumero))
             sFracao=str(fNumero - int(sInteiro))
          sFracao=sFracao[2:(tam_dec+2)]
          fNumero=float(sInteiro + "." + sFracao)
          return fNumero
       except:
          self.codErro = 4
          return -1


   def getCodErro(self):
       """RetornaCodErro, Retorna o codigo do erro econtrado """
       return self.codErro

   def getDescErro(self):
       """RetornaDescErro, Retorna a descricao do erro econtrado """
       return self.listaDeErros[self.codErro]

def getNumToStr(numero, inteiro=0, decimal=0, comPonto='S'):
    """formata um numero em string, com o tamanho 'inteiro' especificado e
       o tamanho 'decimal' especificado
       se 'comPonto' for = 'S', a string retornada contera um '.' separando a parte inteira da decimal
                  """
    n=Numero(numero)
    sN=n.numeroToStr(inteiro, decimal)
    if sN == -1:
       return -1
    if comPonto!='N':
       return str(sN)
    if decimal == 0:
        sN=sN[:inteiro]
    else:
        sN=sN[:inteiro] + sN[(decimal*-1):]
    return str(sN)

def getNumeroEditado(number, decimals=2, dec_point=',', thousands_sep='.'):
   try:
       number = round(float(number), decimals)
   except ValueError:
       return number
   neg = number < 0
   integer, fractional = str(abs(number)).split('.')
   m = len(integer) % 3
   if m:
       parts = [integer[:m]]
   else:
       parts = []
   
   parts.extend([integer[m+t:m+t+3] for t in xrange(0, len(integer[m:]), 3)])
   
   if decimals:
       return '%s%s%s%s' % (
           neg and '-' or '', 
           thousands_sep.join(parts), 
           dec_point, 
           fractional.ljust(decimals, '0')[:decimals]
       )
   else:
       return '%s%s' % (neg and '-' or '', thousands_sep.join(parts))   

# fim de avo

==> sigutils-2.4.2.tar.gz: sigutils-2.4.2/SigUtils/numero.py <==
# -*- coding: iso-8859-1 -*-
from SigUtils import formatastring

__Autor__ = "Luiz Fernando"
__Empresa__ = "Sig Informatica Ltda"
__Site__ = "http://www.siginformatica.com.br"
__Versao__ = "1.06"
__DataAlteracao__ = "27/10/2009"
import sys

if __name__ == '__main__':
    try:
        if sys.argv[1] == '-9':
            print('numeros.py\t\tVersao:' + __Versao__ + '\tData:'+ __DataAlteracao__) + '\tTratamento de valores numericos'
        else:
           print('\n\nnumeros.py - Tratamento de valores numericos \n'
                   +'Versao: '+ __Versao__ + '\n'
                   +'Data: '+ __DataAlteracao__ + '\n')
    except:
       print('\n\nnumeros.py - Tratamento de valores numericos \n'
               +'Versao: '+ __Versao__ + '\n'
               +'Data: '+ __DataAlteracao__ + '\n')


class Numero:
   """sintaxe: Numero(ValorNumerico) -> Objeto 
      Numero trata valores numericos, formatando para strings
      ou truncando / arredondando
      Para qualquer erro, retorna -1
                                      """

   def __init__(self, numero):
       self.codErro=0
       self.listaDeErros=(
          "vazio",                                                                # 0
          "Tamanho da parte inteira maior do que o tamanho especificado",         # 1
          "Tamanho da parte fracionada maior do que o tamanho especificado",      # 2
          "'trunc_round' so pode ser 't' ou 'r'",                                 # 3
          "Valor Informando nao  numerico",                                      # 4
          "vazio")
       try:
          a=str(numero)
          if len(a) == 0:
             self.numero=0.0
          else:   
             self.numero = float(a)
       except:
          self.codErro=4 


   def numeroToStr(self, tam_int=0, tam_fra=0):
       """numeroToStr, converte numeros em strings
          Sintaxe: NumeroToStr([tam_int], [[tam_fra])
          'tam_int',  o tamanho da parte inteira 
          'tam_fra"  o tamanho da parte fracionada
          se tam_int e/ou tam_fra nao forem informados o retorno da funcao 
             ser exatamente do tamanho real do numero, se informado, ser
             expandido para o tamanho especificado
                   
                                         """
       try:
          if self.codErro==4:
             return -1
          sNumero=str(self.numero)
          if tam_int == 0:
             return sNumero
          sInteiro = str(int(self.numero))
          if len(sInteiro) > tam_int:
             self.codErro=1
             return -1
          sInteiro = formatastring.formataString(sInteiro, tam_int, '0', 'E')
          sFracao=''
          iniciou = 'N'
          for x in sNumero:
              if x == '.': 
                 iniciou = 'S'
                 continue
              if iniciou == 'S':
                 sFracao=sFracao+x
          if len(sFracao) > tam_fra :
             sFracao=sFracao[:tam_fra]
          sFracao= formatastring.formataString(sFracao, tam_fra, '0', 'D')
          sNumero=sInteiro+'.'+sFracao
          return sNumero
       except:
          self.codErro = 4
          return -1
   def numeroToFloat(self, tam_dec=0, trunc_round='r'):
       """numeroToFloat, Converte numeros em float
        Sintaxe: NumeroToFloat([tam_dec], [trunc_round])
        'tam_dec'  o tamanho da parte decimal(fracao)
        'trunc_round' especifica se  para truncar ou arredondar caso o numero informado seja maior
        se 'tam_dec' nao for informado, o retorno da funcao sera  exatamente do tamanho real do numero,
           se for informado, sera truncado ou arredondado conforme 'trunc_round' = 't' ou 'r'
                                                    """
       try:
          if self.codErro==4:
             return -1
          if trunc_round != 'r' and trunc_round !='t':
             self.codErro=3
             return -1
          fNumero=float(self.numero)       
          if tam_dec == 0:
             return fNumero
          sInteiro = str(int(fNumero))
          sFracao = str(fNumero - int(sInteiro))
          if len(sFracao) <= tam_dec:
             return fNumero
          if trunc_round == 'r':
             fNumero=round(fNumero, tam_dec)
             sInteiro = str(int(fNumero))
             sFracao=str(fNumero - int(sInteiro))
          sFracao=sFracao[2:(tam_dec+2)]
          fNumero=float(sInteiro + "." + sFracao)
          return fNumero
       except:
          self.codErro = 4
          return -1


   def getCodErro(self):
       """RetornaCodErro, Retorna o codigo do erro econtrado """
       return self.codErro

   def getDescErro(self):
       """RetornaDescErro, Retorna a descricao do erro econtrado """
       return self.listaDeErros[self.codErro]

def getNumToStr(numero, inteiro=0, decimal=0, comPonto='S'):
    """formata um numero em string, com o tamanho 'inteiro' especificado e
       o tamanho 'decimal' especificado
       se 'comPonto' for = 'S', a string retornada contera um '.' separando a parte inteira da decimal
                  """
    n=Numero(numero)
    sN=n.numeroToStr(inteiro, decimal)
    if sN == -1:
       return -1
    if comPonto!='N':
       return str(sN)
    if decimal == 0:
        sN=sN[:inteiro]
    else:
        sN=sN[:inteiro] + sN[(decimal*-1):]
    return str(sN)

def getNumeroEditado(number, decimals=2, dec_point=',', thousands_sep='.'):
   try:
       number = round(float(number), decimals)
   except ValueError:
       return number
   neg = number < 0
   integer, fractional = (('%.' + str(decimals or 1) + 'f') % abs(number)).split('.')
   m = len(integer) % 3
   if m:
       parts = [integer[:m]]
   else:
       parts = []
   
   parts.extend([integer[m+t:m+t+3] for t in xrange(0, len(integer[m:]), 3)])
   
   if decimals:
       return '%s%s%s%s' % (
           neg and '-' or '', 
           thousands_sep.join(parts), 
           dec_point, 
           fractional.ljust(decimals, '0')[:decimals]
       )
   else:
       return '%s%s' % (neg and '-' or '', thousands_sep.join(parts))   

# fim de avo
